@@ -21,7 +21,7 @@ from six import string_types
 logger = logging.getLogger(__name__)
 
 
-VERSION = '0.4.3'
+VERSION = '0.4.4'
 __author__ = 'joke2k'
 __version__ = tuple(VERSION.split('.'))
 
@@ -76,8 +76,10 @@ class Env(object):
         'postgis': 'django.contrib.gis.db.backends.postgis',
         'mysql': 'django.db.backends.mysql',
         'mysql2': 'django.db.backends.mysql',
+        'mysql-connector': 'mysql.connector.django',
         'mysqlgis': 'django.contrib.gis.db.backends.mysql',
         'oracle': 'django.db.backends.oracle',
+        'pyodbc': 'sql_server.pyodbc',
         'redshift': 'django_redshift_backend',
         'spatialite': 'django.contrib.gis.db.backends.spatialite',
         'sqlite': 'django.db.backends.sqlite3',
@@ -114,6 +116,7 @@ class Env(object):
     DEFAULT_SEARCH_ENV = 'SEARCH_URL'
     SEARCH_SCHEMES = {
         "elasticsearch": "haystack.backends.elasticsearch_backend.ElasticsearchSearchEngine",
+        "elasticsearch2": "haystack.backends.elasticsearch2_backend.Elasticsearch2SearchEngine",
         "solr": "haystack.backends.solr_backend.SolrEngine",
         "whoosh": "haystack.backends.whoosh_backend.WhooshEngine",
         "xapian": "haystack.backends.xapian_backend.XapianEngine",
@@ -126,6 +129,9 @@ class Env(object):
     def __call__(self, var, cast=None, default=NOTSET, parse_default=False):
         return self.get_value(var, cast=cast, default=default, parse_default=parse_default)
 
+    def __contains__(self, var):
+        return var in self.ENVIRON
+
     # Shortcuts
 
     def str(self, var, default=NOTSET):
@@ -452,8 +458,8 @@ class Env(object):
                 scheme = url.scheme.replace('cache', '')
             else:
                 scheme = 'unix'
-
-            config['LOCATION'] = scheme + '://' + url.netloc + url.path
+            locations = [scheme + '://' + loc + url.path for loc in url.netloc.split(',')]
+            config['LOCATION'] = locations[0] if len(locations) == 1 else locations
 
         if url.query:
             config_options = {}
@@ -542,7 +548,7 @@ class Env(object):
 
         if url.scheme == 'simple':
             return config
-        elif url.scheme in ['solr', 'elasticsearch']:
+        elif url.scheme in ['solr', 'elasticsearch', 'elasticsearch2']:
             if 'KWARGS' in params.keys():
                 config['KWARGS'] = params['KWARGS'][0]
 
@@ -556,7 +562,7 @@ class Env(object):
                 config['TIMEOUT'] = cls.parse_value(params['TIMEOUT'][0], int)
             return config
 
-        if url.scheme == 'elasticsearch':
+        if url.scheme in ['elasticsearch', 'elasticsearch2']:
 
             split = path.rsplit("/", 1)
 
@@ -718,9 +724,14 @@ class Path(object):
         if isinstance(other, int):
             return self.path('../' * other)
         elif isinstance(other, string_types):
-            return Path(self.__root__.rstrip(other))
+            if self.__root__.endswith(other):
+                return Path(self.__root__.rstrip(other))
         raise TypeError(
-            "unsupported operand type(s) for -: '{0}' and '{1}'".format(self, type(other)))
+            "unsupported operand type(s) for -: '{self}' and '{other}' "
+            "unless value of {self} ends with value of {other}".format(
+                self=type(self), other=type(other)
+            )
+        )
 
     def __invert__(self):
         return self.path('..')
